	PROGRAM GEOMAPS

*******************************************************************************
*   THIS PROGRAM READS DIGITAL LINE DATA AND CREATES AN ANNOTATION FILE OF    *
*   THE DATA TO BE USED WITH INTERACTIVE SURFACE MODELING VERSION 6.93B.      *
*   THE PROGRAM IS RAN FROM WITHIN THE VMS FILE GEOMENU.COM                   *
*                                                                             *
*   SUBROUTINES CALLED:                                                       *
*     XGEODATA:  READS THE ORIGINAL DATA WITHIN THE SELECTED BOUNDARIES AND   *
*                SELECTED MINOR FEATURE CODES.  THEN PLACES THE DATA INTO     *
*                AN ISM ANNOTATION FILE.                                      *
*     PROJ:      CHANGES THE DATA CONTAINED IN THE ANNOTATION FILE FROM       *
*                ALBERS EQUAL AREA PROJECTION TO THE REQUESTED PROJECTION     *
*                                                                             *
*   VAX/VMS SYSTEM CALLS:                                                     *
*     LIB$ERASE_PAGE:  CLEAR SCREEN                                           *
*                                                                             *
*   VARIABLES:                                                                *
*     REPLY:    DETERMINES IF DATA WILL CONVERTED TO DIFFERENT PROJECTION     *
*     DATA:     DATA WRITTEN TO THE FINAL OUTPUT ANNOTATION FILE              *
*     FOR016:   FINAL OUTPUT FILENAME IF DATA CONVERTED TO DIFFERENT          *
*               PROJECTION                                                    *
*     NATIONAL: DETERMINES IF MAP WILL BE PLACED WITH OTHER REGIONS           *
*                                                                             *
*   LAST MODIFIED:  DECEMBER 15, 1989                                         *
*   AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                            *
*             U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY             *
*******************************************************************************

	CHARACTER*2 REPLY,NATIONAL
        CHARACTER*24 DATA
        CHARACTER*80 FOR016

        I=LIB$ERASE_PAGE(1,1)
        CALL XGEODATA(NATIONAL)

  5     PRINT 10
 10       FORMAT(/,' WOULD YOU LIKE TO CHANGE FROM ALBERS EQUAL-AREA
     +  CONIC',/,' TO ANOTHER PROJECTION (Y/N)? ',$)
        READ (5,15,ERR=20) REPLY
 15     FORMAT(2A)

        IF ((REPLY .EQ .'Y') .OR. (REPLY .EQ. 'y') .OR.
     +      (REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) GOTO 30
 20     TYPE 25    
 25       FORMAT(/,' BAD ENTRY, PLEASE ANSWER WITH Y OR N')
        GO TO 5

*******************************************************************************
*   IF THE ORIGINAL DATA WILL NOT BE CONVERTED FROM THE ALBERS EQUAL AREA     *
*   TO A DIFFERENT PROJECTION THE DATA FILE IS CLOSED                         *
*******************************************************************************

 30     IF ((REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) THEN
            CLOSE (12,STATUS='KEEP')

*******************************************************************************
*   IF REPLY IS YES TO CHANGE THE PROJECTION, THE SUBROUTINE PROJ IS CALLED   *
*******************************************************************************

        ELSE
          I=LIB$ERASE_PAGE(1,1)
          CALL PROJ(NATIONAL)
        END IF

        TYPE 35
 35       FORMAT(/,' JOB COMPLETED')
        END

***************************************************************************

       SUBROUTINE PROJ(NATIONAL)

*    CALLED FROM THE PROGRAM GEOPROJ                                      *
*                                                                         *
*    THIS PROGRAM USES THE SUBROUTINE GTRNW0 FROM THE GENERAL             *
*    CARTOGRAPHIC TRANSFORMATION PACKAGE TO CONVERT THE X-Y POINTS        *
*    OF AN ISM ANNOTATION FILE CREATED IN THE PROGRAM MAP.  THE           *
*    PROJECTION IS CHANGED FROM ALBERS EQUAL AREA TO THE SELECTED         *
*    PROJECTION.                                                          *
*                                                                         *
*    SUBROUTINES CALLED:                                                  *
*      GTRNW0: CONTAINED IN THE GENERAL CARTOGRAPHIC TRANSFORMATION       *
*              PACKAGE (GCTP) FORTRAN PROGRAM, THIS SUBROUTINE            *
*              CALCULATES THE NEW PROJECTION                              *
*      VERIFY: VERIFIES INPUT                                             *
*      CONVERTPNTS:  CONVERTS FROM RADIANS TO DEGREE DECIMALS             *
*      CHANGEUNITS:  CONVERTS TO UNITS OF FEET, METERS, KMETERS, MILES    *
*                                                                         *
*    VAX/VMS SYSTEM CALLS:                                                *
*      LIB$ERASE_PAGE:  CLEAR SCREEN                                      *
*                                                                         *
*    VARIABLES:                                                           *
*      REPLY:     REPLY OF Y OR N                                         *
*      PROJNUM:   NUMBER OF PROJECTION THE FINAL OUTPUT WILL BE IN        *
*      UNIT:      UNIT (FT,IN) THE DATA WILL BE IN                        *
*      BUFFER:    BUFFER CONTAINING DATA TO BE DECODE                     *
*      LNTYPE:    TYPE OF RECORD FROM ORIGINAL DATA,                      *
*                 L=LINE, N=NODE, A=AREA, REFER TO DLG MANUAL             *
*      LNCT:      LINE COUNTER                                            *
*      RGNUM:     NUMBER OF REGION THE ORIGINAL DATA IS LOCATED           *
*      NATIONAL:  DETERMINES IF MAP WILL BE PLACED WITH OTHER REGIONS     *
*      X:         X COORDINATE FROM ORIGINAL DATA                         *
*      Y:         Y COORDINATE FROM ORIGINAL DATA                         *
*      XO:        X COORDINATE TRANSFORMED INTO FINAL PROJECTION          *
*      YO:        Y COORDINATE TRANSFORMED INTO FINAL PROJECTION          *
*      PARAMNUM:  PARAMETER NUMBER OF PARMO ARRAY TO BE CHANGED           *
*      PARMARAY:  ARRAY OF PARAMETERS OF TYPE ZONE, UNIT TO BE USED       *
*                 IN THE SUBROUTINE GTRNWO, ARRAY SIZE 20x18              *
*                                                                         *
*      THE FOLLOWING VARIABLES ARE USED IN THE SUBROUTINE GTRNWO          *
*      PARMI:     INPUT ARRAY OF PROJECTION PARAMETERS, ARRAY SIZE 15     *
*      PARMO:     OUTPUT ARRAY OF PROJECTION PARAMETERS, ARRAY SIZE 15    *
*      COORDI:    INPUT ARRAY OF X AND Y COORDINATES, ARRAY SIZE 2        *
*      COORDO:    OUTPUT ARRAY OF X AND Y COORDINATES, ARRAY SIZE 2       *
*      INUNIT:    INPUT UNIT CODE OF THE VALUES OF COORDI ARRAY           *
*      IOUNIT:    OUTPUT UNIT CODE OF THE VALUES OF COORDO ARRAY          *
*      INZONE:    INPUT ZONE CODE FOR UNIVERSAL TRANSVERSE MERCATOR AND   *
*                 STATE PLANE COORDINATES, IF NEITHER ZONE=61             *
*      IOZONE:    OUTPUT ZONE CODE FOR UNIVERSAL TRANSVERSE MERCATOR AND  *
*                 STATE PLANE COORDINATES, IF NEITHER ZONE=61             *
*      INTYP:     PROJECTION OF THE INPUT DATA                            *
*      IOTYP:     PROJECTION OF THE OUTPUT DATA                           *
*      IFLAG:     ERROR CODE RETURNED FROM THE SUBROUTINE GTRNWO          *
*                                                                         *
*    LAST MODIFIED:  DECEMBER 15, 1989                                     *
*    AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                       *
*              U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY        *
*                                                                         *
***************************************************************************

        CHARACTER*2 NATIONAL,REPLY
        CHARACTER*24 BUFFER
        INTEGER LNCT,IFLAG,RGNUM,PROJNUM,INTYP,IOTYP,INZONE,
     +          IOZONE,IOUNIT,INUNIT,LNTYPE,UNIT,PARAMNUM  
        REAL*8 PARMI(15),PARMO(15),COORDI(2),COORDO(2),
     +     PARMARAY(0:20,18),XO,YO,X,Y

        OPEN(UNIT=10,FILE='EAGLE3:[SIMMERMAN.MAP]PARAM.DAT',
     +       STATUS='OLD',ACCESS='SEQUENTIAL')
        REWIND (12)

        OPEN(UNIT=13,FILE='FOR012',STATUS='NEW',ACCESS='SEQUENTIAL',
     +       CARRIAGECONTROL='LIST')
        I=LIB$ERASE_PAGE(1,1)

******************************************************************************
*  ASK USER FOR PROJECTION NUMBER AND UNITS CHOICE                           *
******************************************************************************

  15    TYPE 20
  20    FORMAT(' PROJECTION TYPES:'/,
     +  '           0=GEOGRAPHIC'/,
     +  '           1=UNIVERSAL TRANSVERSE MERCATOR'/,
     +  '           2=STATE PLANE COORDINATES'/,
     +  '           3=ALBERS CONICAL EQUAL AREA'/,
     +  '           4=LAMBERT CONFORMAL CONIC'/,
     +  '           5=MERCATOR'/,
     +  '           6=POLAR STEROGRAPHIC'/,
     +  '           7=POLYCONIC'/,
     +  '           8=EQUIDISTANT CONIC'/,
     +  '           9=TRANSVERSE MERCATOR'/,
     +  '          10=STEREOGRAPHIC'/,
     +  '          11=LAMBERT AZIMUTHAL EQUAL AREA'/,
     +  '          12=AZIMUTHAL EQUIDISTANT'/,
     +  '          13=GNOMIC'/,
     +  '          14=ORTHOGRAPHIC'/,
     +  '          15=GENERAL VERTICAL NEAR-SIDE'/,
     +  '          16=SINUSOIDAL'/,
     +  '          17=EQUIRECTANGULAR'/,
     +  '          18=MILLER CYLINDRICAL'/,
     +  '          19=VAN DER GRINTEN'/,
     +  '          20=OBLIQUE MERCATOR'/)
       TYPE 25
  25   FORMAT(' ENTER THE NUMBER OF THE PROJECTION: ',$)  
       READ(5,30,ERR=35)PROJNUM
  30   FORMAT(I2)     
       IF ((PROJNUM .GT. 20) .OR. (PROJNUM .LT. 0)) THEN
  35      I=LIB$ERASE_PAGE(1,1) 
          TYPE*,' BAD ENTRY, PLEASE ENTER ANOTHER PROJECTION NUMBER'
          GO TO 15
       END IF         
       IF (PROJNUM .NE. 0) THEN     
          I=LIB$ERASE_PAGE(1,1)
          I=LIB$ERASE_PAGE(10,1)   

   40     TYPE 45
   45     FORMAT(' UNIT CHOICES: '//,
     +        '       0)METERS'/,
     +        '       1)FEET'/,
     +        '       2)KILOMETERS'/,
     +        '       3)MILES'//,
     +        ' ENTER UNIT CHOICES (0,1,2 OR 3):  ', $)
          READ (5,30,ERR=50) UNIT
          IF ((UNIT .LT. 0) .OR. (UNIT .GT. 3))THEN
   50         I=LIB$ERASE_PAGE(10,1)   
             TYPE*,'BAD ENTRY, PLEASE ENTER ANOTHER UNIT CHOICE '
             GOTO 40
          END IF
       END IF 

*****************************************************************************
*  READING FROM PARAM.DAT FILE TO FILL PARMARAY.  PARMARAY IS A             *
*  (0-20,18) ARRAY.  ROWS 0-20 REPRESENT EACH PROJECTION (ORDER IS          *
*  AS ABOVE). COLUMNS 1-3 REPRESENT TYPE,ZONE,UNIT RESPECTIVELY,            *
*  4-18 REPRESENT THE PARAMETERS FOR PARMI AND PARMO. THE DATA CORRESPONDS  *
*  TO UNITED STATES REGION.                                                 *
*****************************************************************************

        READ(10,*,END=55)((PARMARAY(I,J),J=1,18),I=0,20)

*****************************************************************************
*  ALL IN-PARAMETERS FOR THE SUBROUTINE GTRNWO ARE SET TO ALBERS EQUAL AREA.*
*  ALL OUT-PARAMETERS ARE SET TO THE CORRESPONDING PROJECTION NUMBER.       *
*  REFER TO THE GCTP MANUAL FOR PARAMETERS FOR EACH PROJECTION.             *
*****************************************************************************

   55   DO 60,J=1,15
             PARMI(J)=PARMARAY(3,J+3)
             PARMO(J)=PARMARAY(PROJNUM,J+3)
   60   CONTINUE
        INTYP=PARMARAY(3,1)  
        INZONE=PARMARAY(3,2)
        INUNIT=PARMARAY(3,3)
        IOUNIT=PARMARAY(PROJNUM,3)
        IOTYP=PARMARAY(PROJNUM,1)
        IOZONE=PARMARAY(PROJNUM,2)

*****************************************************************************   
*  IF PROJNUM IS 1 OR 2 (UTM OR STATE PLANES) THEN THE IOZONE VALUE         *
*  MUST BE ENTERED BY THE USER.  REFER TO THE GCTP MANUAL FOR CODE VALUES   *
*****************************************************************************

        IF ((PROJNUM .EQ. 1) .OR. (PROJNUM .EQ. 2)) THEN
           IF (PROJNUM .EQ. 1) THEN
   65         I=LIB$ERASE_PAGE(1,1)
              I=LIB$ERASE_PAGE(10,1)   
              TYPE 70
   70         FORMAT (' ENTER UTM CODE (REFER TO THE GCTP MANUAL):',$)
              READ(5,75,ERR=65) IOZONE
   75         FORMAT(I5)
           END IF
           IF (PROJNUM .EQ. 2) THEN
   80         TYPE 85
   85         FORMAT(//,' ENTER STATE PLANE ZONE CODE (REFER TO 
     +                    THE GCTP MANUAL):',$)
              READ(5,75,ERR=80) IOZONE
           END IF
        END IF
   90  I=LIB$ERASE_PAGE(1,1)
       I=LIB$ERASE_PAGE(10,1)  

************************************************************************
*  ASKING USER FOR THE REGION NUMBER AND CHANGING THE VALUES           *
*  OF PARMI AND PARMO 3-6.                                             *
************************************************************************

       TYPE 95
   95  FORMAT(' IN WHAT MAJOR AREA IS THE ANNOTATION FILE FROM:'//,
     +        '               1=CONTINENTAL UNITED STATES'/,
     +        '               2=HAWAIIAN ISLANDS'/,
     +        '               3=ALASKA'//,
     +        ' ENTER THE MAJOR AREA (1,2,OR 3): ',$)
       READ(5,30,ERR=100) RGNUM
       IF ((RGNUM .GT. 3) .OR. (RGNUM .LE. 0)) THEN
  100     I=LIB$ERASE_PAGE(1,1)
          I=LIB$ERASE_PAGE(10,1)   
          TYPE*,'BAD ENTRY, PLEASE ENTER ANOTHER REGION NUMBER'
          GO TO 90
       END IF

       IF (RGNUM .EQ. 2) THEN
            PARMI(3)=0.800000000000000D+07
            PARMO(3)=PARMI(3)
            PARMI(4)=0.180000000000000D+08
            PARMO(4)=PARMI(4)
            PARMI(5)=-0.157000000000000D+09
            PARMO(5)=PARMI(5)
            PARMI(6)=0.300000000000000D+07
            PARMO(6)=PARMI(6)
       END IF
       IF (RGNUM .EQ. 3) THEN
            PARMI(3)=0.550000000000000D+08
            PARMO(3)=PARMI(3)
            PARMI(4)=0.650000000000000D+08
            PARMO(4)=PARMI(4)
            PARMI(5)=-0.154000000000000D+09   
            PARMO(5)=PARMI(5)
            PARMI(6)=0.5000000000000000D+07
            PARMO(6)=PARMI(6) 
       END IF
***********************************************************************
* SPECIAL CASE: FOR PROJECTION 9 AND 20, PARMI(3) MUST BE SET TO 1.0  *
* PARMI(3) REPRESENTS THE SCALE FACTOR AT THE CENTRAL MERIDIAN.       *
***********************************************************************

      IF ((PROJNUM .EQ. 9) .OR. (PROJNUM .EQ. 20))
     +        PARMO(3)=1.0

***********************************************************************
* THE DATA IN PARMI IS SET FOR NATIONAL MAPS.  THEREFORE              *
* IT IS NECESSARY TO CHANGE THE PARAMETERS OF PARMI IF THE            *
* MAP IS NOT ON A NATIONAL LEVEL.                                     *
***********************************************************************

      IF ((NATIONAL .EQ. 'N') .OR. (NATIONAL .EQ. 'n'))THEN
           I=LIB$ERASE_PAGE(1,1)
           TYPE 105
  105      FORMAT(' THE FOLLOWING INFORMATION IS NEEDED FOR THE'/,
     +            ' REGION BEING MAPPED: ')

  110      TYPE 115
  115      FORMAT(' ENTER THE LATITUDE OF FIRST STANDARD PARALLEL: ',$)
           READ(5,120,ERR=110)PARMI(3)          
  120      FORMAT(D) 
           CALL VERIFY(PARMI(3),NOTCORRECT)
           IF (NOTCORRECT) GOTO 110      

  125      TYPE 130     
  130      FORMAT(' ENTER THE LATITUDE OF SECOND STANDARD PARALLEL: ',$)
           READ(5,120,ERR=125)PARMI(4)
           CALL VERIFY(PARMI(4),NOTCORRECT)
           IF (NOTCORRECT) GOTO 125      

  135      TYPE 140
  140      FORMAT(' ENTER THE LONGITUDE OF CENTRAL MERIDIAN: ',$)
           READ(5,120,ERR=135)PARMI(5)              
           CALL VERIFY(PARMI(5),NOTCORRECT)
           IF (NOTCORRECT) GOTO 135      

  145      TYPE 150
  150      FORMAT(' ENTER THE LATITUDE OF ORIGIN OF PROJECTION: ',$)
           READ(5,120,ERR=145)PARMI(6)              
           CALL VERIFY(PARMI(6),NOTCORRECT)
           IF (NOTCORRECT) GOTO 145      

  155      TYPE 160
  160      FORMAT(' ENTER FALSE EASTING AT CENTRAL MERIDIAN: ',$)
           READ(5,120,ERR=155)PARMI(7)          
           CALL VERIFY(PARMI(7),NOTCORRECT)
           IF (NOTCORRECT) GOTO 155      

  165      TYPE 170
  170      FORMAT(' ENTER FALSE NORTHING AT ORIGIN: ',$)
           READ(5,120,ERR=165)PARMI(8)
           CALL VERIFY(PARMI(8),NOTCORRECT)
           IF (NOTCORRECT) GOTO 165      
      END IF

************************************************************************
* ASKING IF THERE ARE ANY PARAMETER CHANGES FOR PARMO                  *
************************************************************************

      I=LIB$ERASE_PAGE(1,1)    
  175 PRINT 180, PROJNUM
  180 FORMAT(/,' WOULD YOU LIKE TO CHANGE ANY OF THE PARAMETERS'/,
     +        ' OF THE NUMBER' ,I3, ' PROJECTION (Y/N): ',$)  
      READ(5,182,ERR=175)REPLY
  182 FORMAT(A)

      IF ((REPLY .EQ. 'Y') .OR. (REPLY .EQ. 'y') .OR.
     +    (REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) GOTO 190
      TYPE 185    
  185 FORMAT(/,' BAD ENTRY, PLEASE ANSWER WITH Y OR N',/)
      GO TO 175

  190 IF ((REPLY .EQ. 'Y') .OR. (REPLY .EQ. 'y')) THEN
         PARAMNUM=1
         DO WHILE (PARAMNUM .NE. 0 )
  195        TYPE 200
  200        FORMAT(/,' ENTER THE PARAMETER NUMBER THAT YOU WANT',
     +       ' TO CHANGE'/, ' OR A 0 (ZERO) TO QUIT: ',$)
             READ(5,30,ERR=205)PARAMNUM
             IF ( PARAMNUM .EQ. 0) GOTO 260

             IF (PARAMNUM .LT. 1 .OR. PARAMNUM .GT. 15) THEN
  205           PRINT*,'BAD ENTRY, PARAMETER NUMBERS ARE 1-15'
                GO TO 195
             END IF

             GOTO 215
  210        PRINT*,'BAD ENTRY'
  215        PRINT 220, PARAMNUM,PROJNUM
  220        FORMAT(/,' ENTER THE VALUE FOR PARAMETER NUMBER ', I2,
     +                ' PROJECTION NUMBER  ',I2,' : ',$)

             READ(5,225,ERR=210)PARMO(PARAMNUM)
  225        FORMAT(D)    
  230        PRINT 235, PARAMNUM,PARMO(PARAMNUM)
  235        FORMAT(/,' THE VALUE FOR PARAMETER NUMBER ',I3,
     +                ' IS: ',F20.5)

  240        PRINT 245 
  245        FORMAT(/,' IS THIS CORRECT Y/N? ',$)
             READ(5,182,ERR=250) REPLY
             IF ((REPLY .EQ. 'Y') .OR. (REPLY .EQ. 'y') .OR.
     +           (REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) GOTO 255
  250        TYPE*,(' BAD ENTRY, PLEASE ENTER Y OR N')
             GO TO 230
  255        IF ((REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) GOTO 215   
         END DO 
      END IF

**************************************************************************
*  CONVERTING POINTS FROM ISM ANOTATION FILE AND WRITING                 *
*  TO A THE OUTPUT FILE.                                                 *
**************************************************************************

  260  LNCT=0
  265  READ(12,270,END=300)BUFFER
  270  FORMAT(A24)
       IF (BUFFER(1:1) .EQ. 'S') THEN
          DECODE(2,275,BUFFER(8:9))LNTYPE
  275     FORMAT(I2)
          WRITE(13,280)LNTYPE    
  280     FORMAT('SRFLNE',I2,', 1, 0')  
          LNCT=LNCT + 1
       ELSE
          DECODE(24,285,BUFFER)X,Y           
  285     FORMAT(F12.0,F12.0)
          COORDI(1)=X
          COORDI(2)=Y
          CALL GTRNW0(COORDI,INTYP,INZONE,PARMI,INUNIT,COORDO,
     +               IOTYP,IOZONE,PARMO,IOUNIT,IFLAG)
          IF (IFLAG .NE. 0) THEN 
            TYPE*,' ERROR CODE FOR GCTP = ',IFLAG,' AT POINT ',LNCT           
          END IF
          IF (PROJNUM .EQ. 0) THEN
             CALL CONVERTPNTS(COORDO)
             XO=COORDO(1)
             YO=COORDO(2)
             WRITE(13,290)XO,YO
  290        FORMAT(2 F24.9)
             GO TO 295
          END IF
          X=COORDO(1)
          Y=COORDO(2)
          CALL CHANGEUNITS(X,Y,UNIT)
          WRITE(13,285)X,Y
  295  END IF
       GO TO 265
  300  TYPE 305,LNCT
  305  FORMAT(' CONVERSION IS COMPLETED.'/,' CONVERTED ',
     +          I5,' LINES')

       CLOSE(12,STATUS='DELETE')
       CLOSE(13,STATUS='KEEP')
       CLOSE(10,STATUS='KEEP')

       RETURN
       END

***************************************************************************
*    SUBROUTINE VERIFY IS USED TO VERIFY INPUT OF VALUE OF A PARAMETER    *
*    CALLED FROM THE SUBROUTINE PROJ                                      *
*                                                                         *
*    VARIABLES:                                                           *
*      VALUE:       VALUE OF THE PARAMETER                                *
*      NOTCORRECT:  BOOLEAN CHECKING IF ANSWER IS CORRECT                 * 
*                                                                         *
*    LAST MODIFIED:  AUGUST 11, 1989                                      *
*    AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                       *
*              U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY        *
*                                                                         *
***************************************************************************

         SUBROUTINE VERIFY(VALUE,NOTCORRECT)

         LOGICAL NOTCORRECT
         REAL VALUE

         NOTCORRECT=.FALSE.
    5    PRINT 10, VALUE
   10    FORMAT(' IS THIS CORRECT Y/N ',D,': ',$) 
         READ(5,15,ERR=20) REPLY
   15    FORMAT(A)
         IF ((REPLY .EQ. 'Y') .OR. (REPLY .EQ. 'y') .OR.
     +       (REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) GOTO 25
   20    TYPE*,(' BAD ENTRY, PLEASE ENTER Y OR N')
   25    IF ((REPLY .EQ. 'N') .OR. (REPLY .EQ. 'n')) THEN
            PRINT*,'PLEASE ENTER THE VALUE AGAIN'
            NOTCORRECT=.TRUE.
         END IF
         RETURN
         END

***************************************************************************
*  SUBROUTINE CONVERTPNTS TAKES A RADIAN VALUE AND CONVERTS IT TO         *
*  DECIMAL DEGREES.                                                       *
*  CALLED FROM THE SUBROUTINE PROJ                                        *
*                                                                         *
*    VARIABLES:                                                           *
*      PI:      VALUE OF PI                                               *
*      COORDO:  X AND Y COORDINATE TO BE CONVERTED                        *
*                                                                         *
*    LAST MODIFIED:  AUGUST 11, 1989                                      *
*    AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                       *
*              U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY        *
*                                                                         *
***************************************************************************

         SUBROUTINE CONVERTPNTS(COORDO)
         DATA PI/3.141592653589793D0/
         REAL*8 COORDO(2)
         DO 5, I=1,2
         COORDO(I)=(COORDO(I) * 360)/(2 * PI)           
 5       CONTINUE
         RETURN
         END   
      
***************************************************************************
*  SUBROUTINE CHANGEUNITS WILL CHANGE THE UNITS OF INPUT ACCORDING TO THE *
*  ANSWER (0=METERS,1=FEET,2=KILIOMETERS,3=MILES).                        *
*  CALLED FROM THE SUBROUTINE PROJ                                        *
*                                                                         *
*    VARIABLES:                                                           *
*      X:     X COORDINATE                                                *
*      Y:     Y COORDINATE                                                *
*      UNIT:  UNIT THE VALUE WILL BE CHANGED TO                           *
*                                                                         *
*    LAST MODIFIED:  AUGUST 11, 1989                                      *
*    AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                       *
*              U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY        *
*                                                                         *
***************************************************************************

       SUBROUTINE CHANGEUNITS(X,Y,UNIT)

       REAL*4 X,Y,UNIT

       IF (UNIT .EQ. 1) THEN
          X = X/0.305
          Y = Y/0.305
       END IF
       IF (UNIT .EQ. 2) THEN
          X = X/1000
          Y = Y/1000
       END IF
       IF (UNIT .EQ. 3) THEN
          X = X/1000*0.62
          Y = Y/1000*0.62
       END IF

       RETURN          
       END
*******************************************************************************
        SUBROUTINE XGEODATA(NATIONAL)

*   CALLED FROM THE PROJGRAM GEOPROJ                                          *
*                                                                             *
*   THIS PROGRAM READS THE 1:2000000 GEODATA THEN PLACES THE DATA INTO        *
*   AN INTERACTIVE SURFACE MODELING (ISM), VERSION 6.93B ANNOTATION FILE      *
*   WITHIN THIS PROGRAM THE USER IS ABLE TO SELECT DATA WITHIN SPECIFIED      *
*   BOUNDARIES, SELECT DATA WHICH IS ONLY A CERTAIN MINOR FEATURE CODE AND    *
*   REORIENT THE DATA TO ROTATIONAL MOSAIC IF THE GEODATA WILL BE USED WITH   *
*   OTHER GEODATA REGIONS                                                     *
*                                                                             *
*   SUBROUTINES CALLED:                                                       *
*     GTRNWO:  CONTAINED IN THE GENERAL CARTOGRAPHIC TRANSFORMATION           *
*              PACKAGE (GCTP) FORTRAN PROGRAM, THIS SUBROUTINE CONVERTS       *
*              THE GIVEN LATITUDE AND LONGITUDE BOUNDARIES FROM GEOGRAPHIC    *
*              ALBER'S EQUAL AREA PROJECTION                                  *
*                                                                             *
*   VARIABLES:                                                                *
*     DISPLAY:   DISPLAYS THE LINE COUNT IF Y                                 *
*     NATIONAL:  IF Y, REORIENTS THE ORIGINAL DATA TO BE USED WITH OTHER DATA *
*     RETURN:    ALLOWS USER TO READ THE INFORMATION THEN GO FORWARD          *
*     DTYPE:     TYPE OF ORIGINAL DATA, SUCH AS ROAD AND TRAILS               *
*     FILNM:     THE FILENAME OF THE ORIGINAL DATA TO BE USED                 *
*     LNTYPE:    TYPE OF RECORD FROM ORIGINAL DATA,                           *
*                L=LINE, N=NODE, A=AREA, REFER TO DLG MANUAL                  *
*     LNREM:     THE HEADER OF THE RECORD TYPE OF LINE WHICH CONTAINS THE     *
*                LINE NUMBER, NUMBER OF POINTS, NUMBER OF MINOR CODES         *
*     LNCNT:     NUMBER OF LINES IN THE ORIGINAL DATA                         *
*     LNNO:      LINE NUMBER IN THE ORIGINAL DATA                             *
*     LNPTS:     NUMBER OF POINTS WITHIN EACH LINE                            *
*     LNCLS:     ARRAY OF MINOR FEATURE CODES, ARRAY SIZE 20                  *
*                REFER TO THE GEOMENU MANUAL OR DLG MANUAL FOR LIST           *
*     LNIDS:     NUMBER OF MINOR FEATURE CODES FOR EACH LINE                  *
*     MINCOD:    DETERMINES IF MINOR FEATURE CODES WILL BE SELECTED           *
*     LINTYPE:   TYPE OF LINE TO BE PLOTTED IN ISM                            *
*     NTYPES:    NUMBER OF MINOR FEATURE CODES TO SEARCH FOR                  *
*     MNTYPES:   ARRAY OF SELECTED MINOR FEATURE CODES, ARRAY SIZE 50         *
*     CNT:       COUNTER                                                      *
*     CLASSEQ:   VALUE TO DETERMINE IF LINES ARE SELECTED MINOR FEATURE CODES *
*     A1 - A4:   FOUR VALUES USED TO REORIENT THE DATA                        *
*     COORD:     ARRAY OF THE FOUR CORNER LATITUDE AND LONGITUDE COORDINATES, *
*                ARRAY SIZE 8                                                 *
*     MAPRM:     ARRAY OF PROJECTION PARAMETERS USED IN THE SUBROUTINE        *
*                GTRNWO, ARRAY SIZE 15, REFER TO THE GCTP DOCUMENTATION       *
*     PI:        VALUE OF PI, USED TO CONVERT FROM DEGREES TO RADIANS         *
*     X:         ARRAY OF LONGITUDE VALUE OF BOUNDARIES USED, ARRAY SIZE 2    *
*     Y:         ARRAY OF LATITUDE VALUE OF BOUNDARIES USED, ARRAY SIZE 2     *
*     XY:        ARRAY OF X Y POINTS FROM ORIGINAL DATA, ARRAY SIZE 20000     *
*     TEMPXY:    ARRAY OF X Y POINTS CONVERTED, ARRAY SIZE 20000              *
*     MIDX:      CENTRE LONGITUDE POINT IN DECIMAL DEGREES                    *
*     MIDY:      CENTRE LATITUDE POINT IN DECIMAL DEGREES                     *
*     IMIDX:     INTEGER VALUE OF CENTRE LONGITUDE POINT                      *
*     IMIDY:     INTEGER VALUE OF CENTRE LATITUDE POINT                       *
*     PDEGREEX:  DEGREE VALUE OF X IN PACKED FORMAT                           *
*     PDEGREEY:  DEGREE VALUE OF Y IN PACKED FORMAT                           *
*     MINUTEX:   MINUTE VALUE OF X                                            *
*     MINUTEY:   MINUTE VALUE OF Y                                            *
*     INTMINX:   INTEGER MINUTE VALUE OF X                                    *
*     INTMINY:   INTEGER MINUTE VALUE OF Y                                    *
*     PMINUTEX:  MINUTE VALUE OF X IN PACKED FORMAT                           *
*     PMINTUEY:  MINUTE VALUE OF Y IN PACKED FORMAT                           *
*     SECONDX:   SECOND VALUE OF X                                            *
*     SECONDY:   SECOND VALUE OF Y                                            *
*     PSECONDX:  SECOND VALUE OF X IN PACKED FORMAT                           *
*     PSECONDY:  SECOND VALUE OF Y IN PACKED FORMAT                           *
*     XMID:      VALUE OF CENTRE LONGITUDE POINT IN PACKED FORMAT             *
*     YMID:      VALUE OF CENTRE LATITUDE POINT IN PACKED FORMAT              *
*                                                                             *
*   THE FOLLOWING VARIABLES ARE USED IN THE SUBROUTINE GTRNWO                 *
*     PARMI:     INPUT ARRAY OF PROJECTION PARAMETERS, ARRAY SIZE 15          *
*     PARMO:     OUTPUT ARRAY OF PROJECTION PARAMETERS, ARRAY SIZE 15         *
*     COORDI:    INPUT ARRAY OF X AND Y COORDINATES, ARRAY SIZE 2             *
*     COORDO:    OUTPUT ARRAY OF X AND Y COORDINATES, ARRAY SIZE 2            *
*     INUNIT:    INPUT UNIT CODE OF THE VALUES OF COORDI ARRAY                *
*     IOUNIT:    OUTPUT UNIT CODE OF THE VALUES OF COORDO ARRAY               *
*     INZONE:    INPUT ZONE CODE FOR UNIVERSAL TRANSVERSE MERCATOR AND        *
*                STATE PLANE COORDINATES, IF NEITHER ZONE=61                  *
*     IOZONE:    OUTPUT ZONE CODE FOR UNIVERSAL TRANSVERSE MERCATOR AND       *
*                STATE PLANE COORDINATES, IF NEITHER ZONE=61                  *
*     INTYP:     PROJECTION OF THE INPUT DATA                                 *
*     IOTYP:     PROJECTION OF THE OUTPUT DATA                                *
*     IFLAG:     ERROR CODE RETURNED FROM THE SUBROUTINE GTRNWO               *
*                                                                             *
*   LAST MODIFIED:  DECEMBER 15, 1989                                          *
*   AUTHORS:  CALAE K. RUNGE, KENNETH I. TAKAHASHI                            *
*              U.S. GEOLOGICAL SURVEY, BRANCH OF PETROLEUM GEOLOGY            *
*                                                                             *
*******************************************************************************

      CHARACTER*2  DISPLAY,LNTYPE,NATIONAL,RETURN
      CHARACTER*20 DTYPE
      CHARACTER*40 FILNM
      CHARACTER*48 LNREM

      DOUBLEPRECISION A1,A2,A3,A4,COORD(8),MAPRM(15),
     +                PI,X(2),Y(2),XY(20000),TEMPXY(20000),
     +                PARMI(15),PARMO(15),COORDI(2),COORDO(2)

      REAL*4 MINUTEX,MINUTEY,PMINUTEX,PMINUTEY,SECONDX,
     +       SECONDY,PSECONDX,PSECONDY,PDEGREEX,PDEGREEY,
     +       XMID,YMID,MIDX,MIDY

      INTEGER*4 I,LNCNT,LNNO,LNPTS,LNCLS(20),LINTYPE,
     +          LNIDS,MINCOD,CNT,NTYPES,MNTYPES(50),CLASSEQ,
     +          IMIDX,IMIDY,INTMINX,INTMINY,IFLG,
     +          INTYP,IOTYP,INZONE,IOZONE,INUNIT,IOUNIT

      DATA PI/3.1415926535/,INTYP/0/,IOTYP/3/,INZONE/61/,
     +     IOZONE/61/,INUNIT/0/,IOUNIT/2/

**************************************************************************
* OPEN THE OUTPUT DATA FILE                                              *
**************************************************************************

      OPEN(UNIT=12,FILE='FOR012',CARRIAGECONTROL='LIST',
     +     STATUS='NEW')

**************************************************************************
*  DETERMINE IF THE MAP WILL BE ON A NATIONAL LEVEL, IF YES THE MAP      *
*  WILL BE PLACED WITH OTHER REGIONAL MAPS FROM THE DIGITAL LINE GRAPHS  *
*  IF ON A NATIONAL LEVEL THE MAP WILL BE REORIENTED TOWARDS THE END     *
*  OF THE PROGRAM                                                        *
**************************************************************************

   5  TYPE 10
  10  FORMAT(/,' WILL THIS MAP BE USED'/,
     +         ' ON A NATIONAL LEVEL (Y/N)?: ',$)
      READ(5,15,ERR=20) NATIONAL
  15  FORMAT(A2)
      IF ((NATIONAL .EQ.'Y').OR.(NATIONAL .EQ. 'y').OR. 
     +    (NATIONAL .EQ. 'N').OR.(NATIONAL .EQ. 'n')) GOTO 25 
  20  PRINT*,'BAD ENTRY, PLEASE ANSWER WITH Y OR N'
      GOTO 5

*****************************************************************************
*  THE MINOR FEATURE CODES ARE CODES TO DETERMINE THE TYPE OF LINE          *
*  EXAMPLE: CODE NUMBER 3095 IS A INTERCOASTAL WATERWAY                     *
*  FOR A LISTING OF THE CODES REFER TO THE MANUAL OR THE "USGS DIGITAL      *
*  CARTOGRAPHIC DATA STANDARDS", GEOLOGICAL SURVEY CIRCULAR 895-D           *
*****************************************************************************

  25  TYPE 30
  30  FORMAT(/,' ENTER 1 TO SELECT A MINOR FEATURE CODE'/,
     +         ' OR 0 TO GET ALL TYPES OF MINOR'/,
     +         ' FEATURE CODES : ',$)
      READ(5,35,ERR=40) MINCOD
  35  FORMAT(I6)
      IF (MINCOD .NE. 0 .AND. MINCOD .NE. 1) THEN 
  40     PRINT*,'BAD ENTRY, ANSWER WITH 0 OR 1'
         GO TO 25
      END IF

      IF (MINCOD .NE. 0) THEN
         NTYPES=1
  45     TYPE 50
  50     FORMAT(/,' ENTER A MINOR FEATURE CODE (REFER TO MANUAL)'/, 
     +            ' FOR SELECTION, OR A ZERO TO QUIT: ',$)       
         READ(5,35,ERR=55)MNTYPES(NTYPES)
         IF (MNTYPES(NTYPES) .LT. 0 .OR. 
     +       MNTYPES(NTYPES) .GT. 999999) THEN
  55       PRINT*,'BAD ENTRY, ANSWER WITH A NUMBER FOR THE FEATURE CODE'
           GO TO 45
         END IF
         IF (MNTYPES(NTYPES) .EQ.0) THEN
           NTYPES=NTYPES - 1
           GO TO 60
         END IF
         NTYPES=NTYPES + 1
         GO TO 45
  60  END IF

*******************************************************************************
*  DETERMINE THE TYPE OF LINES TO BE USED WHEN PLOTTING A MAP USING ISM       *
*******************************************************************************

  65  TYPE 70
  70  FORMAT(/,' LINE TYPES ARE:'/' 1=SOLID'/' 2=BOLD'/
     +         ' 3=SHORT DASH'/' 4=MEDIUM DASH'/' 5=LONG DASH'/
     +         ' 6=MEDIUM/SHORT DASH'/' 7=LONG/SHORT DASH'/
     +         ' 8=MEDIUM/TWO SHORT DASH'/' 9=LONG/TWO SHORT DASH'/
     +         ' 10=SOLID HASHED'/
     +         ' PLEASE ENTER THE LINE TYPE (1-10): ',$)
      READ(5,75,ERR=80)LINTYPE
  75  FORMAT(I2)
      IF (LINTYPE .LT. 1 .OR. LINTYPE .GT. 10)THEN
  80    PRINT *, ' '
        PRINT*, 'BAD ENTRY, PLEASE ANSWER WITH 1-10' 
        PRINT *, ' '
        GOTO 65
      END IF

*******************************************************************************
*  RETRIEVE INFORMATION FROM THE HEADER OF THE ORIGINAL DATA, DETERMINED FROM *
*  THE COMMAND FILE GEOMENU.COM.  THE INFORMATION RETREIVED CONTAINS DATA TO  *
*  BE USED IN THE CONVERSION OF LATITUDE AND LONGITUDE BOUNDARIES AND THE     *
*  ORIGINAL BOUNDARIES OF THE DATA.                                           *
*******************************************************************************

      READ(11,85,END=999)FILNM
  85  FORMAT(A40)
      TYPE 90, FILNM
  90  FORMAT(/,' WORKING ON ',A40/)
      READ(11,95,END=999)(MAPRM(J),J=1,15)
  95  FORMAT(18X,5D24.15/6D24.14/4D24.15)
      TYPE 100, (MAPRM(J),J=1,15)
 100  FORMAT (' THE 15 PROJECTION PARAMETERS ARE: '/,
     +          5(D24.14,' ',D24.14,' ',D24.14/))
      READ(11,105,END=999)(COORD(I),I=1,8)
 105  FORMAT(6D24.15/2D24.15)
      TYPE 110,(COORD(I),I=1,8)
 110  FORMAT(' THE COORDINATES OF THE FOUR CORNERS ARE:'/
     +         4(F11.5,' ',F11.5/))
      READ(11,115,END=999)A1,A2,A3,A4,DTYPE,LNCNT
 115  FORMAT(4D24.15///A20,30X,I6)
      TYPE 120, A1,A2,A3,A4
 120  FORMAT (' A1 - A4 VALUES USED FOR REORIENTATION ARE: '/,
     +          2(D24.15,' ',D24.15/))
      MIDX=(COORD(1)+COORD(7))/2
      MIDY=(COORD(2)+COORD(4))/2
      TYPE 125,MIDX,MIDY
 125  FORMAT(' CENTER POINT COORDINATES ARE:'/' LONGITUDE= ',F11.5,
     + /' LATITUDE= ',F11.5, /)
      TYPE 130
 130  FORMAT(' HIT RETURN TO CONTINUE ',$) 
      READ(5,'(A)')RETURN

*****************************************************************************
*  ASK USER IF THEY WANT TO USE THE ENTIRE REGION OR SELECT A BOUNDARY      *
*  IF THEY SELECT A BOUNDARY, THE VALUE ENTERED WILL BE CHECKED TO SEE IF   *
*  IT IS WITHIN THE ORIGINAL DATA BOUNDARY                                  *
*****************************************************************************

 135  TYPE 140
 140  FORMAT(/,' ENTER MINIMUM X (LONGITUDE) VALUE IN DEGREES DECIMAL '/,
     +  ' OR 0 FOR ENTIRE REGION: ',$)
      READ(5,145,ERR=150)X(1)
 145  FORMAT(F10.5)
      IF(X(1) .EQ. 0) GO TO 215

****************************************************************************
*  THE 8 VALUES OF COORD ARE PAIRS OF LATITUDE AND LONGITUDE OF THE        *
*  CORNERS OF THE REGIONAL MAP.  THESE COORD VALUES ARE RETREIVED FROM     *
*  HEADER OF THE ORIGINAL DATA NEAR THE BEGINNING OF THIS PROGRAM.         *
*  THE VALUES OF COORD ARE NOT EXACT.  THE BOUNDARIES ARE ACTUALLY WITHIN  *
*  5 DEGREES OF THE COORD VALUES, THIS IS THE REASON FOR ADDING AND        *
*  SUBTRACTING 5 DEGREES TO THE COORD VALUES.  SINCE THE ORIGINAL DATA IS  *
*  ONLY FOR THE UNITED STATES, THE LONGITUDE MUST BE LESS THAN ZERO AND    *
*  THE LATITUDE MUST BE GREATER THAN ZERO.                                 *
****************************************************************************

      IF (ABS(X(1)) .LT. (ABS(COORD(5))-5.0) .OR. 
     +    ABS(X(1)) .GT. (ABS(COORD(1))+5.0) .OR. X(1) .GT. 0) THEN
 150      PRINT *, ' INCORRECT ANSWER, NOT WITHIN THE MAP REGION '
          GOTO 135
      ENDIF
 155  TYPE 160
 160  FORMAT(' ENTER MAXIMUM X (LONGITUDE) VALUE IN DEGREES DECIMAL ',$)
      READ(5,145,ERR=165)X(2)

      IF (ABS(X(2)) .LT. ABS(COORD(5))-5.0 .OR. 
     +    ABS(X(2)) .GT. ABS(COORD(1))+5.0 .OR. X(2) .GT. 0) THEN
 165      PRINT *, ' INCORRECT ANSWER, NOT WITHIN THE MAP REGION '
          GOTO 155
      ENDIF
 170  TYPE 175
 175  FORMAT(' ENTER MINIMUM Y (LATITUDE) VALUE IN DEGREES DECIMAL ',$)
      READ(5,145,ERR=180)Y(1)
      IF (ABS(Y(1)) .LT. ABS(COORD(2))-5.0 .OR. 
     +    ABS(Y(1)) .GT. ABS(COORD(4))+5.0 .OR. Y(1) .LT. 0) THEN
 180      PRINT *, ' INCORRECT ANSWER, NOT WITHIN THE MAP REGION '
          GOTO 170
      ENDIF
 185  TYPE 190
 190  FORMAT(' ENTER MAXIMUM Y (LATITUDE) VALUE IN DEGREES DECIMAL ',$)
      READ(5,145,ERR=195)Y(2)
      IF (ABS(Y(2)) .LT. ABS(COORD(2))-5.0 .OR. 
     +    ABS(Y(2)) .GT. ABS(COORD(4))+5.0 .OR. Y(2) .LT. 0) THEN
 195      PRINT *, ' INCORRECT ANSWER, NOT WITHIN THE MAP REGION '
          GOTO 185
      ENDIF

***************************************************************************
*  THE LINE COUNT OF LINES INCLUDED WITHIN THE BOUNDARIES WILL BE         *
*  DISPLAYED IF REPLYED WITH YES                                          *
***************************************************************************

 200  TYPE 205
 205  FORMAT(' DO YOU WANT TO DISPLAY THE LINE COUNT?: (Y or N) ',$)
      READ(*,210)DISPLAY
 210  FORMAT (A)
      IF (DISPLAY .NE. 'N' .AND. DISPLAY .NE. 'n' .AND. 
     +    DISPLAY .NE. 'Y' .AND. DISPLAY .NE. 'y') THEN
          PRINT *, ' BAD ENTRY, ANSWER MUST BY Y OR N '
          GOTO 200
      ENDIF

***************************************************************************
*  BEGIN CONVERTING THE BOUNDARIES OF X AND Y FROM GEOGRAPHIC TO ALBERS   *
***************************************************************************

 215  IF (X(1) .NE. 0) THEN
        DO 220, J=1,15
           PARMO(J) = MAPRM(J)
           PARMI(J) = 0.0
 220    CONTINUE

**************************************************************************
*  CONVERT THE MIDDLE X AND Y FROM DECIMAL DEGREE TO PACKED FORMAT       *
*  TO BE USED IN THE CONVERSION OF THE LATITUDE AND LONGITUDE BOUNDARIES *
**************************************************************************

        IMIDX = INT(MIDX)
        PDEGREEX = REAL(IMIDX)
        MINUTEX = AMOD(MIDX,1.0)
        MINUTEX = MINUTEX*60.0
        INTMINX = INT(MINUTEX)
        PMINUTEX = REAL(INTMINX)
        SECONDX = AMOD(MINUTEX,1.0)
        PSECONDX = SECONDX*60.0
        XMID = (PDEGREEX*1000000) + (PMINUTEX*1000) + PSECONDX

        IMIDY = INT(MIDY)
        PDEGREEY = REAL(IMIDY)
        MINUTEY = AMOD(MIDY,1.0)
        MINUTEY = MINUTEY*60.0
        INTMINY = INT(MINUTEY)
        PMINUTEY = REAL(INTMINY)
        SECONDY = AMOD(MINUTEY,1.0)
        PSECONDY = SECONDY*60.0
        YMID = (PDEGREEY*1000000.0) + (PMINUTEY*1000.0) + PSECONDY

****************************************************************************
* CONVERT THE BOUNDARIES FROM GEOGRAPHIC TO ALBERS TO CORRESPOND WITH      *
* THE ORIGINAL DATA, BY CALLING GTRNW0                                     *
****************************************************************************

        PARMO(5) = XMID
        PARMO(6) = YMID
        DO 235, I = 1,2
          X(I) = (X(I)*(2*PI))/360.0
          Y(I) = (Y(I)*(2*PI))/360.0
          COORDI(1) = X(I)
          COORDI(2) = Y(I)
          CALL GTRNW0(COORDI,INTYP,INZONE,PARMI,INUNIT,COORDO,
     +                IOTYP,IOZONE,PARMO,IOUNIT,IFLAG)
          IF (IFLAG .NE. 0)THEN 
             TYPE*,' ERROR CODE FOR GCTP = ',IFLAG          
          END IF
          X(I) = COORDO(1)
          Y(I) = COORDO(2)

****************************************************************************
*  CONVERT THE LATITUDE AND LONGITUDE BOUNDARIES FROM METRES TO            *
*  THOUSANDTHS OF AN INCH (50.8KM/INCH - FROM THE SCALE OF THE NATIONAL    *
*  ATLAS MAPS) TO CORRESPOND WITH THE ORIGINAL DATA                        *
****************************************************************************

          X(I) = X(I)/50.8
          Y(I) = Y(I)/50.8
          TYPE 225, I,X(I)
 225      FORMAT (' X(',I1,') IN ALBERS EQUAL-AREA = ',F20.7)
          TYPE 230, I,Y(I)
 230      FORMAT (' Y(',I1,') IN ALBERS EQUAL-AREA = ',F20.7)
 235    CONTINUE
      END IF
      IF (X(1) .NE. 0) THEN
         TYPE 240
 240     FORMAT(' HIT RETURN TO CONTINUE ',$) 
         READ(5,245)RETURN
 245     FORMAT(A)
      ENDIF

      TYPE 250, DTYPE,LNCNT
 250  FORMAT(/,' DATA TYPE IS ',A20,' WITH ',I6,' LINES')

*******************************************************************************
*  ONLY THE DATA WHICH ARE LINES (L) WILL BE USED.  THE OTHER LINES REPRESENT *
*  NODES (N) AND AREAS (A).  FOR FURTHER EXPLAINATION REFER TO THE PROGRAM    *
*  MANUAL OR THE "USGS DIGITAL CARTOGRAPHIC DATA STANDARDS", CIRCULAR 895-D   *
*******************************************************************************

 255  READ(11,260,END=998) LNTYPE,LNREM
 260  FORMAT(A2,A48)
      IF (LNTYPE .NE. 'L ')GO TO 255

*******************************************************************************
*  DETERMINE THE NUMBER OF LINES, NUMBER OF X Y COORDINATE PAIRS, AND THE     *
*  NUMBER OF MINOR FEATURE CODES THAT DESCRIBE THE LINE.  FOR FURTHER         *
*  INFORMATION REFER TO THE USGS CIRCULAR 895-D                               *
*******************************************************************************

      DECODE(48,265,LNREM)LNNO,LNPTS,LNIDS
 265  FORMAT(I6,24X,2I6,6X)

      IF (DISPLAY .EQ. 'Y' .OR. DISPLAY .EQ. 'y') THEN 
         TYPE 270,LNNO,LNCNT,LNPTS
 270  FORMAT(/,' WORKING ON ',I6,' OF ',I6,' WITH ',I6,' POINTS')       
      ENDIF
      TLNPTS=LNPTS*2

******************************************************************************
*  READ THE X Y COORDINATE PAIRS FROM THE ORIGINAL DATA                      *
******************************************************************************

      READ(11,275,END=998) (XY(I),I=1,TLNPTS)
 275  FORMAT(24F6.0)

*****************************************************************************
*  IF LATITUDE AND LONGITUDE BOUNDARIES WERE GIVEN CHECK THE X Y COORDINATE *
*  TO DETERMINE IF WITHIN THE BOUNDARIES.  IF X Y IS OUTSIDE OF BOUNDARIES  *
*  THE LINE IS REJECTED                                                     *
*****************************************************************************

      IF (X(1) .EQ. 0) GO TO 290
      DO 280 I=1,TLNPTS,2
 280  IF(((XY(I) .LE. X(2)) .AND. (XY(I) .GE. X(1))) .AND.
     +  ((XY(I+1) .LE. Y(2)) .AND. (XY(I+1) .GE. Y(1)))) GO TO 290
      IF (DISPLAY .EQ. 'Y' .OR. DISPLAY .EQ. 'y') TYPE 285
 285  FORMAT(/,' LINE REJECTED, OUTSIDE XY WINDOW')
      GO TO 255

***************************************************************************
*  CHECK MINOR FEATURE CODES IF ALL MINOR CODES ARE NOT REQUESTED         *
*  IF MINOR CODE FOR LINE DOES NOT MATCH THE REQUESTED CODES, THE LINE    *
*  IS REJECTED.                                                           *
***************************************************************************

 290  IF (MINCOD .EQ. 0 .OR. MNTYPES(1) .EQ. 0) GO TO 315
      IF (LNIDS .EQ. 0) GO TO 255
      READ(11,295,END=999) (LNCLS(I),I=1,LNIDS)
 295  FORMAT(12(6X,I6))
      CLASSEQ = 1
      DO 305, I=1, NTYPES
        DO 300,J=1,LNIDS
          IF (LNCLS(J) .NE. MNTYPES(I)) THEN
             IF (I .EQ. NTYPES .AND. J .EQ. LNIDS) THEN
	        IF (CLASSEQ .EQ. 0) GO TO 315
	        GO TO 255 
	     ENDIF
	  ELSE
	    CLASSEQ = 0
          END IF
 300    CONTINUE
 305  CONTINUE
      IF (DISPLAY .EQ. 'Y' .OR. DISPLAY .EQ. 'y') THEN
	 TYPE 310
 310     FORMAT(/,' LINE REJECTED, WRONG TYPE')
      ENDIF

**************************************************************************
*  CONVERSION FROM THOUSANDTHS OF AN INCH TO METERS                      *
*  IF NATIONAL IS Y, REORIENT THE DATA TO A COMMON REFERENCE POINT       *
**************************************************************************
 315  DO 320, I=1,TLNPTS,2
         IF (NATIONAL.EQ.'Y'.OR.NATIONAL.EQ.'y')THEN
           TEMPXY(I)=(A1*XY(I))+(A2*XY(I+1))+A3
           TEMPXY(I+1)=(A1*XY(I+1))-(A2*XY(I))+A4
         ELSE
           TEMPXY(I)=(XY(I)*50800)/1000
           TEMPXY(I+1)=(XY(I+1)*50800)/1000
         END IF
 320  CONTINUE

**************************************************************************
*  WRITE THE SRFLINE (LINE TYPE) AND X Y COORDINATE TO THE OUTPUT FILE   *
*  IN THE ISM FORMAT                                                     *
**************************************************************************

      WRITE(12,325) LINTYPE
 325  FORMAT('SRFLNE ',I2,', 1, 0')
      WRITE(12,330) (TEMPXY(I),TEMPXY(I+1),I=1,TLNPTS,2)
 330  FORMAT(F12.0,F12.0)
      CNT=CNT+1
      IF (DISPLAY .EQ. 'Y' .OR. DISPLAY .EQ. 'y') TYPE 335
 335  FORMAT(/,' LINE INCLUDED')
      GO TO 255
 999  TYPE 340
 340  FORMAT(' BAD FILE')
 998  TYPE 345, CNT
 345  FORMAT(' FINISHED, ',I6,' LINES INCLUDED')
      CLOSE(11,STATUS='KEEP')
      RETURN
      END  

